#[non_exhaustive]pub enum ApplicationError {
NotInitialized,
AlreadyRunning,
NotRunning,
StillRunning,
Bot(TelegramError),
UpdateProcessor(UpdateProcessorError),
Webhook(String),
}Expand description
Errors from the Application itself.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotInitialized
The application was not initialized before use.
AlreadyRunning
The application is already running and cannot be started again.
NotRunning
The application is not currently running.
StillRunning
The application is still running and cannot be shut down yet.
Bot(TelegramError)
An error from the underlying Telegram Bot API.
UpdateProcessor(UpdateProcessorError)
An error from the update processor subsystem.
Webhook(String)
A webhook-related error.