pub struct Handler {
pub check_update: Arc<dyn Fn(&Update) -> bool + Send + Sync>,
pub callback: HandlerCallback,
pub block: bool,
}Expand description
A registered handler: the check_update predicate + callback + blocking flag.
Fields
check_update: Arc<dyn Fn(&Update) -> bool + Send + Sync>Predicate that determines whether this handler matches an update.
callback: HandlerCallbackThe async callback invoked when the handler matches.
block: boolIf true, the application awaits this handler before moving to the next group.