Defaults

Struct Defaults 

pub struct Defaults { /* private fields */ }
Convenience struct to gather all parameters with a (user defined) default value.

Fields that are None indicate “no default was set” and will not be injected into API calls.

Implementations

Source

impl Defaults

pub fn builder() -> DefaultsBuilder

Returns a new DefaultsBuilder for ergonomic construction.

Example
let defaults = Defaults::builder()
    .parse_mode("HTML")
    .protect_content(true)
    .build();
pub fn parse_mode(&self) -> Option<&str>

Send Markdown or HTML – if you want Telegram apps to show bold, italic, fixed-width text or URLs in your bot’s message.

pub fn explanation_parse_mode(&self) -> Option<&str>

Alias for parse_mode, used for the corresponding parameter of Bot::send_poll.

pub fn text_parse_mode(&self) -> Option<&str>

Alias for parse_mode, used for InputPollOption and Bot::send_gift.

pub fn question_parse_mode(&self) -> Option<&str>

Alias for parse_mode, used for Bot::send_poll.

pub fn quote_parse_mode(&self) -> Option<&str>

Alias for parse_mode, used for ReplyParameters.

pub fn disable_notification(&self) -> Option<bool>

Sends the message silently.

pub fn allow_sending_without_reply(&self) -> Option<bool>

Pass true if the message should be sent even if the specified replied-to message is not found.

pub fn block(&self) -> bool

Default setting for BaseHandler.block and error handlers.

pub fn protect_content(&self) -> Option<bool>

Protects the contents of the sent message from forwarding and saving.

Link preview generation options for all outgoing messages.

pub fn do_quote(&self) -> Option<bool>

Whether the bot should quote the replied-to message.

pub fn api_defaults(&self) -> &HashMap<String, Value>

Pre-computed mapping of non-None defaults keyed by API parameter name.