#[non_exhaustive]pub enum CallbackPattern {
Data(Regex),
Game(Regex),
Both {
data: Regex,
game: Regex,
},
Predicate(Arc<dyn Fn(&str) -> bool + Send + Sync>),
}Expand description
Pattern to match against callback query data or game short name.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Data(Regex)
Match callback_query.data against this compiled regex.
Game(Regex)
Match callback_query.game_short_name against this compiled regex.
Both
Match both: data against the first regex, game against the second.
Fields
Predicate(Arc<dyn Fn(&str) -> bool + Send + Sync>)
Match callback_query.data using an arbitrary predicate function.
This covers Python’s callable(data) and isinstance(data, type)
patterns in a Rust-idiomatic way. The predicate receives the data
string and returns true if the callback query should be handled.