#[non_exhaustive]pub enum UpdaterError {
AlreadyRunning,
NotRunning,
NotInitialized,
StillRunning,
Bootstrap(String),
}Expand description
Errors that can occur within the Updater lifecycle.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyRunning
The updater is already running and cannot be started again.
NotRunning
The updater is not currently running.
NotInitialized
The updater has not been initialized yet.
StillRunning
The updater is still running and cannot be shut down.
Bootstrap(String)
The bootstrap phase (e.g. deleting webhooks) failed.